package org.apache.bcel.util;

import java.io.Closeable;
import java.io.DataInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FilenameFilter;
import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.nio.file.Files;
import java.nio.file.LinkOption;
import java.nio.file.OpenOption;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Enumeration;
import java.util.List;
import java.util.Locale;
import java.util.Objects;
import java.util.StringTokenizer;
import java.util.Vector;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;

/* loaded from: org_apache_bcel_util.jar:org/apache/bcel/util/ClassPath.class */
public class ClassPath implements Closeable {
    private static final FilenameFilter ARCHIVE_FILTER = (dir, name) -> {
        String name = name.toLowerCase(Locale.ENGLISH);
        return name.endsWith(".zip") || name.endsWith(".jar");
    };
    private static final FilenameFilter MODULES_FILTER = (dir, name) -> {
        return name.toLowerCase(Locale.ENGLISH).endsWith(".jmod");
    };
    public static final ClassPath SYSTEM_CLASS_PATH = new ClassPath(getClassPath());
    private final String classPath;
    private ClassPath parent;
    private final AbstractPathEntry[] paths;

    /* loaded from: org_apache_bcel_util.jar:org/apache/bcel/util/ClassPath$ClassFile.class */
    public interface ClassFile {
        String getBase();

        InputStream getInputStream() throws IOException;

        String getPath();

        long getSize();

        long getTime();
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: org_apache_bcel_util.jar:org/apache/bcel/util/ClassPath$AbstractPathEntry.class */
    public static abstract class AbstractPathEntry implements Closeable {
        abstract ClassFile getClassFile(String str, String str2);

        abstract URL getResource(String str);

        abstract InputStream getResourceAsStream(String str);

        private AbstractPathEntry() {
        }
    }

    /* loaded from: org_apache_bcel_util.jar:org/apache/bcel/util/ClassPath$AbstractZip.class */
    private static abstract class AbstractZip extends AbstractPathEntry {
        private final ZipFile zipFile;

        protected abstract String toEntryName(String str, String str2);

        AbstractZip(ZipFile zipFile) {
            super();
            this.zipFile = (ZipFile) Objects.requireNonNull(zipFile, "zipFile");
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() throws IOException {
            if (this.zipFile != null) {
                this.zipFile.close();
            }
        }

        @Override // org.apache.bcel.util.ClassPath.AbstractPathEntry
        ClassFile getClassFile(String name, String suffix) {
            final ZipEntry entry = this.zipFile.getEntry(toEntryName(name, suffix));
            if (entry == null) {
                return null;
            }
            return new ClassFile() { // from class: org.apache.bcel.util.ClassPath.AbstractZip.1
                @Override // org.apache.bcel.util.ClassPath.ClassFile
                public String getBase() {
                    return AbstractZip.this.zipFile.getName();
                }

                @Override // org.apache.bcel.util.ClassPath.ClassFile
                public InputStream getInputStream() throws IOException {
                    return AbstractZip.this.zipFile.getInputStream(entry);
                }

                @Override // org.apache.bcel.util.ClassPath.ClassFile
                public String getPath() {
                    return entry.toString();
                }

                @Override // org.apache.bcel.util.ClassPath.ClassFile
                public long getSize() {
                    return entry.getSize();
                }

                @Override // org.apache.bcel.util.ClassPath.ClassFile
                public long getTime() {
                    return entry.getTime();
                }
            };
        }

        @Override // org.apache.bcel.util.ClassPath.AbstractPathEntry
        URL getResource(String name) {
            ZipEntry entry = this.zipFile.getEntry(name);
            if (entry == null) {
                return null;
            }
            try {
                return new URL("jar:file:" + this.zipFile.getName() + "!/" + name);
            } catch (MalformedURLException e) {
                return null;
            }
        }

        @Override // org.apache.bcel.util.ClassPath.AbstractPathEntry
        InputStream getResourceAsStream(String name) {
            ZipEntry entry = this.zipFile.getEntry(name);
            if (entry == null) {
                return null;
            }
            try {
                return this.zipFile.getInputStream(entry);
            } catch (IOException e) {
                return null;
            }
        }

        public String toString() {
            return this.zipFile.getName();
        }
    }

    /* loaded from: org_apache_bcel_util.jar:org/apache/bcel/util/ClassPath$Dir.class */
    private static class Dir extends AbstractPathEntry {
        private final String dir;

        Dir(String d) {
            super();
            this.dir = d;
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() throws IOException {
        }

        @Override // org.apache.bcel.util.ClassPath.AbstractPathEntry
        ClassFile getClassFile(String name, String suffix) {
            final File file = new File(this.dir + File.separatorChar + name.replace('.', File.separatorChar) + suffix);
            if (file.exists()) {
                return new ClassFile() { // from class: org.apache.bcel.util.ClassPath.Dir.1
                    @Override // org.apache.bcel.util.ClassPath.ClassFile
                    public String getBase() {
                        return Dir.this.dir;
                    }

                    @Override // org.apache.bcel.util.ClassPath.ClassFile
                    public InputStream getInputStream() throws IOException {
                        return new FileInputStream(file);
                    }

                    @Override // org.apache.bcel.util.ClassPath.ClassFile
                    public String getPath() {
                        try {
                            return file.getCanonicalPath();
                        } catch (IOException e) {
                            return null;
                        }
                    }

                    @Override // org.apache.bcel.util.ClassPath.ClassFile
                    public long getSize() {
                        return file.length();
                    }

                    @Override // org.apache.bcel.util.ClassPath.ClassFile
                    public long getTime() {
                        return file.lastModified();
                    }
                };
            }
            return null;
        }

        @Override // org.apache.bcel.util.ClassPath.AbstractPathEntry
        URL getResource(String name) {
            File file = toFile(name);
            try {
                if (file.exists()) {
                    return file.toURI().toURL();
                }
                return null;
            } catch (MalformedURLException e) {
                return null;
            }
        }

        @Override // org.apache.bcel.util.ClassPath.AbstractPathEntry
        InputStream getResourceAsStream(String name) {
            File file = toFile(name);
            try {
                if (file.exists()) {
                    return new FileInputStream(file);
                }
                return null;
            } catch (IOException e) {
                return null;
            }
        }

        private File toFile(String name) {
            return new File(this.dir + File.separatorChar + name.replace('/', File.separatorChar));
        }

        public String toString() {
            return this.dir;
        }
    }

    /* loaded from: org_apache_bcel_util.jar:org/apache/bcel/util/ClassPath$Jar.class */
    private static class Jar extends AbstractZip {
        Jar(ZipFile zip) {
            super(zip);
        }

        @Override // org.apache.bcel.util.ClassPath.AbstractZip
        protected String toEntryName(String name, String suffix) {
            return ClassPath.packageToFolder(name) + suffix;
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: org_apache_bcel_util.jar:org/apache/bcel/util/ClassPath$JrtModule.class */
    public static class JrtModule extends AbstractPathEntry {
        private final Path modulePath;

        public JrtModule(Path modulePath) {
            super();
            this.modulePath = (Path) Objects.requireNonNull(modulePath, "modulePath");
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() throws IOException {
        }

        @Override // org.apache.bcel.util.ClassPath.AbstractPathEntry
        ClassFile getClassFile(String name, String suffix) {
            final Path resolved = this.modulePath.resolve(ClassPath.packageToFolder(name) + suffix);
            if (Files.exists(resolved, new LinkOption[0])) {
                return new ClassFile() { // from class: org.apache.bcel.util.ClassPath.JrtModule.1
                    @Override // org.apache.bcel.util.ClassPath.ClassFile
                    public String getBase() {
                        return Objects.toString(resolved.getFileName(), null);
                    }

                    @Override // org.apache.bcel.util.ClassPath.ClassFile
                    public InputStream getInputStream() throws IOException {
                        return Files.newInputStream(resolved, new OpenOption[0]);
                    }

                    @Override // org.apache.bcel.util.ClassPath.ClassFile
                    public String getPath() {
                        return resolved.toString();
                    }

                    @Override // org.apache.bcel.util.ClassPath.ClassFile
                    public long getSize() {
                        try {
                            return Files.size(resolved);
                        } catch (IOException e) {
                            return 0L;
                        }
                    }

                    @Override // org.apache.bcel.util.ClassPath.ClassFile
                    public long getTime() {
                        try {
                            return Files.getLastModifiedTime(resolved, new LinkOption[0]).toMillis();
                        } catch (IOException e) {
                            return 0L;
                        }
                    }
                };
            }
            return null;
        }

        @Override // org.apache.bcel.util.ClassPath.AbstractPathEntry
        URL getResource(String name) {
            Path resovled = this.modulePath.resolve(name);
            try {
                if (Files.exists(resovled, new LinkOption[0])) {
                    return new URL("jrt:" + this.modulePath + "/" + name);
                }
                return null;
            } catch (MalformedURLException e) {
                return null;
            }
        }

        @Override // org.apache.bcel.util.ClassPath.AbstractPathEntry
        InputStream getResourceAsStream(String name) {
            try {
                return Files.newInputStream(this.modulePath.resolve(name), new OpenOption[0]);
            } catch (IOException e) {
                return null;
            }
        }

        public String toString() {
            return this.modulePath.toString();
        }
    }

    /* loaded from: org_apache_bcel_util.jar:org/apache/bcel/util/ClassPath$JrtModules.class */
    private static class JrtModules extends AbstractPathEntry {
        private final ModularRuntimeImage modularRuntimeImage;
        private final JrtModule[] modules;

        public JrtModules(String path) throws IOException {
            super();
            this.modularRuntimeImage = new ModularRuntimeImage();
            this.modules = (JrtModule[]) this.modularRuntimeImage.list(path).stream().map(JrtModule::new).toArray(x$0 -> {
                return new JrtModule[x$0];
            });
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() throws IOException {
            if (this.modules != null) {
                for (JrtModule module : this.modules) {
                    module.close();
                }
            }
            if (this.modularRuntimeImage != null) {
                this.modularRuntimeImage.close();
            }
        }

        @Override // org.apache.bcel.util.ClassPath.AbstractPathEntry
        ClassFile getClassFile(String name, String suffix) {
            for (JrtModule module : this.modules) {
                ClassFile classFile = module.getClassFile(name, suffix);
                if (classFile != null) {
                    return classFile;
                }
            }
            return null;
        }

        @Override // org.apache.bcel.util.ClassPath.AbstractPathEntry
        URL getResource(String name) {
            for (JrtModule module : this.modules) {
                URL url = module.getResource(name);
                if (url != null) {
                    return url;
                }
            }
            return null;
        }

        @Override // org.apache.bcel.util.ClassPath.AbstractPathEntry
        InputStream getResourceAsStream(String name) {
            for (JrtModule module : this.modules) {
                InputStream inputStream = module.getResourceAsStream(name);
                if (inputStream != null) {
                    return inputStream;
                }
            }
            return null;
        }

        public String toString() {
            return Arrays.toString(this.modules);
        }
    }

    /* loaded from: org_apache_bcel_util.jar:org/apache/bcel/util/ClassPath$Module.class */
    private static class Module extends AbstractZip {
        Module(ZipFile zip) {
            super(zip);
        }

        @Override // org.apache.bcel.util.ClassPath.AbstractZip
        protected String toEntryName(String name, String suffix) {
            return "classes/" + ClassPath.packageToFolder(name) + suffix;
        }
    }

    private static void addJdkModules(String javaHome, List<String> list) {
        String[] modules;
        String modulesPath = System.getProperty("java.modules.path");
        if (modulesPath == null || modulesPath.trim().isEmpty()) {
            modulesPath = javaHome + File.separator + "jmods";
        }
        File modulesDir = new File(modulesPath);
        if (modulesDir.exists() && (modules = modulesDir.list(MODULES_FILTER)) != null) {
            for (String module : modules) {
                list.add(modulesDir.getPath() + File.separatorChar + module);
            }
        }
    }

    public static String getClassPath() {
        String classPathProp = System.getProperty("java.class.path");
        String bootClassPathProp = System.getProperty("sun.boot.class.path");
        String extDirs = System.getProperty("java.ext.dirs");
        String javaHome = System.getProperty("java.home");
        List<String> list = new ArrayList<>();
        Path modulesPath = Paths.get(javaHome, new String[0]).resolve("lib/modules");
        if (Files.exists(modulesPath, new LinkOption[0]) && Files.isRegularFile(modulesPath, new LinkOption[0])) {
            list.add(modulesPath.toAbsolutePath().toString());
        }
        addJdkModules(javaHome, list);
        getPathComponents(classPathProp, list);
        getPathComponents(bootClassPathProp, list);
        List<String> dirs = new ArrayList<>();
        getPathComponents(extDirs, dirs);
        for (String d : dirs) {
            File extDir = new File(d);
            String[] extensions = extDir.list(ARCHIVE_FILTER);
            if (extensions != null) {
                for (String extension : extensions) {
                    list.add(extDir.getPath() + File.separatorChar + extension);
                }
            }
        }
        StringBuilder buf = new StringBuilder();
        String separator = "";
        for (String path : list) {
            buf.append(separator);
            separator = File.pathSeparator;
            buf.append(path);
        }
        return buf.toString().intern();
    }

    private static void getPathComponents(String path, List<String> list) {
        if (path != null) {
            StringTokenizer tokenizer = new StringTokenizer(path, File.pathSeparator);
            while (tokenizer.hasMoreTokens()) {
                String name = tokenizer.nextToken();
                File file = new File(name);
                if (file.exists()) {
                    list.add(name);
                }
            }
        }
    }

    static String packageToFolder(String name) {
        return name.replace('.', '/');
    }

    @Deprecated
    public ClassPath() {
        this(getClassPath());
    }

    public ClassPath(ClassPath parent, String classPath) {
        this(classPath);
        this.parent = parent;
    }

    public ClassPath(String classPath) {
        this.classPath = classPath;
        List<AbstractPathEntry> list = new ArrayList<>();
        StringTokenizer tokenizer = new StringTokenizer(classPath, File.pathSeparator);
        while (tokenizer.hasMoreTokens()) {
            String path = tokenizer.nextToken();
            if (!path.isEmpty()) {
                File file = new File(path);
                try {
                    if (file.exists()) {
                        if (file.isDirectory()) {
                            list.add(new Dir(path));
                        } else if (path.endsWith(".jmod")) {
                            list.add(new Module(new ZipFile(file)));
                        } else if (path.endsWith(ModularRuntimeImage.MODULES_PATH)) {
                            list.add(new JrtModules(ModularRuntimeImage.MODULES_PATH));
                        } else {
                            list.add(new Jar(new ZipFile(file)));
                        }
                    }
                } catch (IOException e) {
                    if (path.endsWith(".zip") || path.endsWith(".jar")) {
                        System.err.println("CLASSPATH component " + file + ": " + e);
                    }
                }
            }
        }
        this.paths = new AbstractPathEntry[list.size()];
        list.toArray(this.paths);
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() throws IOException {
        if (this.paths != null) {
            for (AbstractPathEntry path : this.paths) {
                path.close();
            }
        }
    }

    public boolean equals(Object o) {
        if (o instanceof ClassPath) {
            ClassPath cp = (ClassPath) o;
            return this.classPath.equals(cp.toString());
        }
        return false;
    }

    public byte[] getBytes(String name) throws IOException {
        return getBytes(name, ".class");
    }

    /* JADX WARN: Failed to apply debug info
    java.lang.NullPointerException: Cannot invoke "jadx.core.dex.instructions.args.InsnArg.getType()" because "changeArg" is null
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.moveListener(TypeUpdate.java:439)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.runListeners(TypeUpdate.java:232)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.requestUpdate(TypeUpdate.java:212)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeForSsaVar(TypeUpdate.java:183)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeChecked(TypeUpdate.java:112)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:83)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.applyWithWiderIgnoreUnknown(TypeUpdate.java:74)
    	at jadx.core.dex.visitors.debuginfo.DebugInfoApplyVisitor.applyDebugInfo(DebugInfoApplyVisitor.java:137)
    	at jadx.core.dex.visitors.debuginfo.DebugInfoApplyVisitor.applyDebugInfo(DebugInfoApplyVisitor.java:133)
    	at jadx.core.dex.visitors.debuginfo.DebugInfoApplyVisitor.searchAndApplyVarDebugInfo(DebugInfoApplyVisitor.java:75)
    	at jadx.core.dex.visitors.debuginfo.DebugInfoApplyVisitor.lambda$applyDebugInfo$0(DebugInfoApplyVisitor.java:68)
    	at java.base/java.util.ArrayList.forEach(ArrayList.java:1597)
    	at jadx.core.dex.visitors.debuginfo.DebugInfoApplyVisitor.applyDebugInfo(DebugInfoApplyVisitor.java:68)
    	at jadx.core.dex.visitors.debuginfo.DebugInfoApplyVisitor.visit(DebugInfoApplyVisitor.java:55)
     */
    /* JADX WARN: Failed to calculate best type for var: r10v0 ??
    java.lang.NullPointerException: Cannot invoke "jadx.core.dex.instructions.args.InsnArg.getType()" because "changeArg" is null
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.moveListener(TypeUpdate.java:439)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.runListeners(TypeUpdate.java:232)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.requestUpdate(TypeUpdate.java:212)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeForSsaVar(TypeUpdate.java:183)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeChecked(TypeUpdate.java:112)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:83)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:56)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.calculateFromBounds(FixTypesVisitor.java:156)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.setBestType(FixTypesVisitor.java:133)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.deduceType(FixTypesVisitor.java:238)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.tryDeduceTypes(FixTypesVisitor.java:221)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.visit(FixTypesVisitor.java:91)
     */
    /* JADX WARN: Failed to calculate best type for var: r10v0 ??
    java.lang.NullPointerException: Cannot invoke "jadx.core.dex.instructions.args.InsnArg.getType()" because "changeArg" is null
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.moveListener(TypeUpdate.java:439)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.runListeners(TypeUpdate.java:232)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.requestUpdate(TypeUpdate.java:212)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeForSsaVar(TypeUpdate.java:183)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeChecked(TypeUpdate.java:112)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:83)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:56)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.calculateFromBounds(TypeInferenceVisitor.java:145)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.setBestType(TypeInferenceVisitor.java:123)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.lambda$runTypePropagation$2(TypeInferenceVisitor.java:101)
    	at java.base/java.util.ArrayList.forEach(ArrayList.java:1597)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.runTypePropagation(TypeInferenceVisitor.java:101)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.visit(TypeInferenceVisitor.java:75)
     */
    /* JADX WARN: Failed to calculate best type for var: r9v0 ??
    java.lang.NullPointerException: Cannot invoke "jadx.core.dex.instructions.args.InsnArg.getType()" because "changeArg" is null
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.moveListener(TypeUpdate.java:439)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.runListeners(TypeUpdate.java:232)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.requestUpdate(TypeUpdate.java:212)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeForSsaVar(TypeUpdate.java:183)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeChecked(TypeUpdate.java:112)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:83)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:56)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.calculateFromBounds(FixTypesVisitor.java:156)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.setBestType(FixTypesVisitor.java:133)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.deduceType(FixTypesVisitor.java:238)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.tryDeduceTypes(FixTypesVisitor.java:221)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.visit(FixTypesVisitor.java:91)
     */
    /* JADX WARN: Failed to calculate best type for var: r9v0 ??
    java.lang.NullPointerException: Cannot invoke "jadx.core.dex.instructions.args.InsnArg.getType()" because "changeArg" is null
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.moveListener(TypeUpdate.java:439)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.runListeners(TypeUpdate.java:232)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.requestUpdate(TypeUpdate.java:212)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeForSsaVar(TypeUpdate.java:183)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.updateTypeChecked(TypeUpdate.java:112)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:83)
    	at jadx.core.dex.visitors.typeinference.TypeUpdate.apply(TypeUpdate.java:56)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.calculateFromBounds(TypeInferenceVisitor.java:145)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.setBestType(TypeInferenceVisitor.java:123)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.lambda$runTypePropagation$2(TypeInferenceVisitor.java:101)
    	at java.base/java.util.ArrayList.forEach(ArrayList.java:1597)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.runTypePropagation(TypeInferenceVisitor.java:101)
    	at jadx.core.dex.visitors.typeinference.TypeInferenceVisitor.visit(TypeInferenceVisitor.java:75)
     */
    /* JADX WARN: Multi-variable type inference failed. Error: java.lang.NullPointerException: Cannot invoke "jadx.core.dex.instructions.args.RegisterArg.getSVar()" because the return value of "jadx.core.dex.nodes.InsnNode.getResult()" is null
    	at jadx.core.dex.visitors.typeinference.AbstractTypeConstraint.collectRelatedVars(AbstractTypeConstraint.java:31)
    	at jadx.core.dex.visitors.typeinference.AbstractTypeConstraint.<init>(AbstractTypeConstraint.java:19)
    	at jadx.core.dex.visitors.typeinference.TypeSearch$1.<init>(TypeSearch.java:376)
    	at jadx.core.dex.visitors.typeinference.TypeSearch.makeMoveConstraint(TypeSearch.java:376)
    	at jadx.core.dex.visitors.typeinference.TypeSearch.makeConstraint(TypeSearch.java:361)
    	at jadx.core.dex.visitors.typeinference.TypeSearch.collectConstraints(TypeSearch.java:341)
    	at java.base/java.util.ArrayList.forEach(ArrayList.java:1597)
    	at jadx.core.dex.visitors.typeinference.TypeSearch.run(TypeSearch.java:60)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.runMultiVariableSearch(FixTypesVisitor.java:116)
    	at jadx.core.dex.visitors.typeinference.FixTypesVisitor.visit(FixTypesVisitor.java:91)
     */
    /* JADX WARN: Not initialized variable reg: 10, insn: 0x008c: MOVE (r0 I:??[int, float, boolean, short, byte, char, OBJECT, ARRAY]) = (r10 I:??[int, float, boolean, short, byte, char, OBJECT, ARRAY]), block:B:31:0x008c */
    /* JADX WARN: Not initialized variable reg: 9, insn: 0x0087: MOVE (r0 I:??[int, float, boolean, short, byte, char, OBJECT, ARRAY]) = (r9 I:??[int, float, boolean, short, byte, char, OBJECT, ARRAY] A[D('inputStream' java.io.InputStream)]) A[TRY_LEAVE], block:B:29:0x0087 */
    /* JADX WARN: Type inference failed for: r10v0, types: [java.lang.Throwable] */
    /* JADX WARN: Type inference failed for: r9v0, names: [inputStream], types: [java.io.InputStream] */
    public byte[] getBytes(String name, String suffix) throws IOException {
        DataInputStream dis = null;
        try {
            try {
                InputStream inputStream = getInputStream(name, suffix);
                Throwable th = null;
                if (inputStream == null) {
                    throw new IOException("Couldn't find: " + name + suffix);
                }
                dis = new DataInputStream(inputStream);
                byte[] bArr = new byte[inputStream.available()];
                dis.readFully(bArr);
                if (inputStream != null) {
                    if (0 != 0) {
                        try {
                            inputStream.close();
                        } catch (Throwable th2) {
                            th.addSuppressed(th2);
                        }
                    } else {
                        inputStream.close();
                    }
                }
                if (dis != null) {
                    dis.close();
                }
                return bArr;
            } finally {
            }
        } catch (Throwable th3) {
            if (dis != null) {
                dis.close();
            }
            throw th3;
        }
    }

    public ClassFile getClassFile(String name) throws IOException {
        return getClassFile(name, ".class");
    }

    public ClassFile getClassFile(String name, String suffix) throws IOException {
        ClassFile cf = null;
        if (this.parent != null) {
            cf = this.parent.getClassFileInternal(name, suffix);
        }
        if (cf == null) {
            cf = getClassFileInternal(name, suffix);
        }
        if (cf != null) {
            return cf;
        }
        throw new IOException("Couldn't find: " + name + suffix);
    }

    private ClassFile getClassFileInternal(String name, String suffix) {
        for (AbstractPathEntry path : this.paths) {
            ClassFile cf = path.getClassFile(name, suffix);
            if (cf != null) {
                return cf;
            }
        }
        return null;
    }

    public InputStream getInputStream(String name) throws IOException {
        return getInputStream(packageToFolder(name), ".class");
    }

    public InputStream getInputStream(String name, String suffix) throws IOException {
        InputStream inputStream = null;
        try {
            inputStream = getClass().getClassLoader().getResourceAsStream(name + suffix);
        } catch (Exception e) {
        }
        if (inputStream != null) {
            return inputStream;
        }
        return getClassFile(name, suffix).getInputStream();
    }

    public String getPath(String name) throws IOException {
        int index = name.lastIndexOf(46);
        String suffix = "";
        if (index > 0) {
            suffix = name.substring(index);
            name = name.substring(0, index);
        }
        return getPath(name, suffix);
    }

    public String getPath(String name, String suffix) throws IOException {
        return getClassFile(name, suffix).getPath();
    }

    public URL getResource(String name) {
        for (AbstractPathEntry path : this.paths) {
            URL url = path.getResource(name);
            if (url != null) {
                return url;
            }
        }
        return null;
    }

    public InputStream getResourceAsStream(String name) {
        for (AbstractPathEntry path : this.paths) {
            InputStream is = path.getResourceAsStream(name);
            if (is != null) {
                return is;
            }
        }
        return null;
    }

    public Enumeration<URL> getResources(String name) {
        Vector<URL> results = new Vector<>();
        for (AbstractPathEntry path : this.paths) {
            URL url = path.getResource(name);
            if (url != null) {
                results.add(url);
            }
        }
        return results.elements();
    }

    public int hashCode() {
        if (this.parent != null) {
            return this.classPath.hashCode() + this.parent.hashCode();
        }
        return this.classPath.hashCode();
    }

    public String toString() {
        if (this.parent != null) {
            return this.parent + File.pathSeparator + this.classPath;
        }
        return this.classPath;
    }
}
